from distutils.core import setup

setup(
       name        = 'oneoppa',
       version     = '1.1.0',
       py_modules  = ['oneoppa'],
       author      = 'xpx1260',
       author_email = 'xpx1260@163.com',
       url          = 'http://email.163.com',
       description ='A simple printer of nested lists',

     )
